/*
 * Entrees:sorties directes sur les cartes MCC et MCX par IOCTL
 *
 * ATTENTION DRIVER UNIX :
 * ^^^^^^^^^^^^^^^^^^^^^
 *		Dans le driver, il n'y a qu'un seul buffer de commandes
 * 		manuelles par voie. Aussi, IL NE FAUT PAS envoyer simultanement
 *		les ioctl() suivants dans PLUSIEURS processes sur le MEME
 *		device (/dev/mccXX). Risque de crash systeme.
 *
 *		Par contre,
 *		- dans le MEME process, sur le meme device, on peut envoyer
 *		  des commandes qui s'appliquent a plusieurs voies DIFFERENTES
 *		  (elles sont alors designees par le parametre par[1] ou par
 *		  le nom du device)
 *		- PLUSIEURS processes peuvent ouvrir chacun un device DIFFERENT
 *		  et envoyer independament leurs commandes.
 *
 * @(#)mcc_mcx.h	3.1 94/04/21 -- JPT
 * Copyright(C) ACKSYS, 1993, 1994.
 */
#ifndef MCC_MCX_H
#define MCC_MCX_H

/* macros and structs for manual commands requests */

#define TIOC_MCC_CMD		(TIOC|99)	/* lancement d'une commde MCX */
#define TIOC_MCC_CMD_AUTO	(TIOC|98)	/* init automatique de par[1] */
#define TIOC_MCC_RUN01		(TIOC|(RUN01))	/* ecriture RUN01 sur mailbox */
#define TIOC_MCC_HUNT		(TIOC|96)	/* non implemente */
#define TIOC_MCX_GET_SYNC_STATE	(TIOC|95)	/* non implemente */
#define TIOC_MCX_SET_SYNC_STATE	(TIOC|94)	/* non implemente */
#define TIOC_MCC_RUN02		(TIOC|(RUN02))	/* ecriture RUN02 sur mailbox */
#define mcc_op(fd,str,op,p1,p2,p3,p4,p5,p6,p7)				\
		(str.opcode=(op), str.par[0]=(p1), str.par[1]=(p2),	\
		str.par[2]=(p3), str.par[3]=(p4), str.par[4]=(p5),	\
		str.par[5]=(p6), str.par[6]=(p7),			\
		(ioctl(fd,TIOC_MCC_CMD,&(str))==-1?-1:str.status))
#define mcx_op	mcc_op

typedef struct mcc_cmd {
	unsigned char opcode;
	unsigned char status;
	unsigned char par[76];
	unsigned char ichan;
	unsigned char icond;
	unsigned char ipar1;
    unsigned char ipar2;
	unsigned char ipar3;
	unsigned char *data;
	unsigned char *kdata;
	unsigned short length;
}mcc_cmd;

typedef struct _MCC_CMD {			/* tampon pour ces ioctls */
	mcc_cmd Cb;				/* l'usage de cette struct */
    unsigned char Data[1];          /* est facultatif sous UNIX */
} MCC_CMD, *PMCC_CMD;

/* taille a allouer pour contenir la struct _MCC_CMD */
#define MCX_DIRECT_IO_BUFFER_SIZE(datalen)	((datalen)+sizeof(mcc_cmd))

#ifndef MCC_NO_CMD		/* permet a l'usager d'inhiber ces defines */
/*
 * Les commandes reperees par *C/X* sont incompatibles entre MCC et MCX
 * Les commandes reperees par *MCC* n'existent pas sur la carte MCX
 * Les commandes reperees par *MCX* n'existent pas sur la carte MCC
 */
#define	VINIT	(char)0	/*C/X*/	/* init. canal de communication asynchrone */	
#define ALLOC	(char)1	/*C/X*/	/* initialisation de la taille des tampons */
#define	ILOAD	(char)2
#define	VMODE	(char)3		/* init. du mode de 'hand-shake' et echo */
#define	RXENB	(char)4		/* activation ou desactivation d'un canal */
#define	MBOOT	(char)5
#define	BDELE	(char)6		/* effacement d'un tampon de trans. et arret */
#define	ISEND	(char)7
#define	BTRAN	(char)8		/* chargement d'un tampon de trans. et envoi */
#define	RDBUF	(char)9		/* lecture d'un tampon de reception */ 
#define	CHDEF	(char)10	/* definition des parametres de chaine */
#define	STCNT	(char)11	/* definition de la taille des blocs */
#define	MINTR	(char)12	/* initialisation du mode d'interruption */
#define	RSTAT	(char)13	/* lecture de l'etat des canaux de com. */
#define	LTEST	(char)14	/* test des canaux de communication */
#define	BTEST	(char)15	/* test automatique de la memoire tampon */
#define	STIME	(char)16	/* mise a l'heure de la carte MCC, MCX */
#define RMEMO	(char)17	/* lecture d'un bloc memoire */	 
#define	GOADR	(char)18	/* execution d'un programme en memoire */
#define	RELRP	(char)19/*C/X*/	/* lecture du No de version,identificateurs */
#define	ENDIT	(char)20	/* commande de fin d'interruption */ 
#define	DALOC	(char)21	/* desallocation des tampons en memoire */
#define	HNGUP	(char)22	/* raccrochage modem */
#define	MTURN	(char)23/*MCC*/	/* retournement de modem */
#define	BPARM	(char)24/*C/X*/	/* lecture des parametres tampons */
#define	RINIT	(char)25	/* reinitialisation de la carte MCC, MCX */
#define	TFREE	(char)26	/* calcul de la place disponible dans TX */
#define	RXCNT	(char)27	/* lecture du nombre de car. dans RX */
#define TMRRP	(char)28	/* lecture de l'heure des communications */
#define	CLRRX	(char)29	/* remise a zero d'un tampon de reception */
#define	IMDWR	(char)30	/* envoi immediat d'une chaine de caracteres */ 
#define	STTMO	(char)31	/* def. des valeurs de Time out en reception */ 
#define ASYSP	(char)32/*MCC*/	/* initialisation vitesses asymetriques */
#define ASYMD	(char)33/*MCC*/	/* passage d'un canal en mode asymetrique */
#define LDIAL	(char)34/*MCC*/	/* numerotation automatique sur ligne modem */
#define BREAK	(char)35	/* envoie d'un break */
#define STSIG	(char)36	/* positionnement manuel de DTR et RTS */
#define MSETP	(char)38/*MCC*/	/* initialisation de la carte OCTOPUCE */
#define TANNU	(char)39/*MCC*/	/* gestion de l'annuaire telephonique integre */
#define ADDCM	(char)40	/* addition d'une commande au jeu standard */
#define ADDTX	(char)41	/* addition d'une fonction en transmission */
#define ADDRX	(char)42	/* addition d'une fonction en reception */
#define NOPER	(char)43	/* pas d'operation */
#define MSIZE	(char)44/*C/X*/	/* lecture configuration memoire */
#define RSMDE	(char)45/*MCX*/	/* initialisation du mode RS232/RS422 */
#define FLASH	(char)46/*MCX*/	/* programmation de la memoire FLASH 256Ko */
#define PROTO	(char)47/*MCX*/	/* init. d'un canal en mode synchrone */
#define PRCTL	(char)48/*MCX*/	/* parametrage des protocoles (MCX-MP) */

#define RUN02	(char)93	/* commande virtuelle, pour mccioctl(1) */
#define RUN01	(char)97	/* commande virtuelle, pour mccioctl(1) */
#define MANUAL	(char)99	/* commande formee par l'usager lui-meme */

#endif /* MCC_NO_CMD */

typedef unsigned char unchar;
typedef struct _MCC_INTERRUPT_STATUS_AREA{
	unchar chan;
	unchar cond;
	unchar par1;
	unchar par2;
	unchar par3;
} MCC_INTERRUPT_STATUS_AREA, *PMCC_INTERRUPT_STATUS_AREA;

typedef struct mcc_mb {
	unchar valid;			/* Offset 0x00 */
#	define busy valid		       /* 0x00 */
	unchar endit;			       /* 0x01 */
	unchar opcode;			       /* 0x02 */
	unchar param[77];		       /* 0x03 */
#   define mcxstatus param[0]      /* 0x03 */
#	define mcxparam  param		/* utiliser mcxparam[1..76] */
	MCC_INTERRUPT_STATUS_AREA i;           /* 0x50 */
	unchar reserve[15-1];		/* -1 pour que data[] commence a 1 */
	unchar data[0x7f00 - 100 + 1];	/* -100 pour les octets precedents */
	unsigned short McxRxCount[64];       /* 0x7F00 */
	unsigned short McxTxFree[32];        /* 0x7F80 */
	unsigned short MccRxCount[16];       /* 0x7FC0 */
	unsigned short MccTxFree[16];        /* 0x7FE0 */
#   define mcxdostring data[0x7F95]      /* 0x7FF8 */
}mcc_mb, MCC_MAILBOX, *PMCC_MAILBOX;

#define MCX_VALID_BUSY      	1
#define MCX_ENDIT_STATRDY   	0x80
#define MCX_ENDIT_ENDIT      	1
#define MCX_STATUS_ERRCMD   	0x80
#define MCX_STATUS_INT_EVENT	0x40	/* interruption evenement */

#define MCX_MINTR_IT0        1  /* interruption sur chaque car. recu */
#define MCX_MINTR_IT1        2  /* interruption sur tampon%STCNT == 0 */
#define MCX_MINTR_IT2        4  /* interruption sur tampon plein */
#define MCX_IT2_NOEMPTY   0x80  /*   "      "   IT2 si RX non vide */
#define MCX_MINTR_IT3        8  /*   "      "   sur chaine programmee */
#define MCX_MINTR_IT4		16	/*   "      "   sur time-out */
#define MCX_MINTR_IT5		32	/*   "      "   sur erreur reception */
#define MCX_IT5_OVERRUN   0x20
#define MCX_IT5_PARITY    0x10
#define MCX_IT5_FRAMING   0x40
#define MCX_MINTR_IT6		64	/* interruption sur delta CTS, etc */
#define MCX_IT6_BREAK     0x80  /* event bits CTS,CD,RI,BREAK in IT6 */
#define MCX_IT6_CTS       0x20
#define MCX_IT6_RING      0x10
#define MCX_IT6_RLSD      0x08
#define MCX_MINTR_IT7      128  /* interruption TX EMPTY */

#define MCX_STSIG_RTS_ON	1	/* placer le RTS a l'etat ACTIF */
#define MCX_STSIG_DTR_ON	2	/* placer le DTR a l'etat ACTIF */

#define MCX_RXENB_ON		1	/* autoriser la reception de car. */
#define MCX_RXENB_OFF		0	/* interdire la reception de car. */

#define MCX_ITREC1          1
#define MCX_ITRECCNT		2
#define MCX_ITRECNOEMPTY	3
#define MCX_ITRECFULL		4
#define MCX_ITCHDEF     	8
#define MCX_ITTMOUT      0x10
#define MCX_ITRECERR     0x20
#define MCX_ITDELTA      0x40
#define MCX_ITTXVIDE     0x80
#define MCX_ITLDIAL      0xC0
#define MCX_RINIT_HARD		1	/* parametre pour RINIT */

/* Extended serial IOCTL codes for Windows NT & 95 */

#if defined(MCXWIN95)

#define FILE_DEVICE_SERIAL_PORT         0x0000001b
#define CTL_CODE( DeviceType, Function, Method, Access ) (                 \
    ((DeviceType) << 16) | ((Access) << 14) | ((Function) << 2) | (Method) \
)

#define METHOD_BUFFERED                 0
#define METHOD_IN_DIRECT                1
#define METHOD_OUT_DIRECT               2
#define METHOD_NEITHER                  3
#define FILE_ANY_ACCESS                 0
#define FILE_READ_ACCESS          ( 0x0001 )    // file & pipe
#define FILE_WRITE_ACCESS         ( 0x0002 )    // file & pipe

#endif  /* Windows 95 */

#if defined(CTL_CODE) && defined(FILE_DEVICE_SERIAL_PORT)

#define MCX_IOCTL(code)			CTL_CODE(FILE_DEVICE_SERIAL_PORT,code,\
						METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_SERIAL_GET_SYNC_STATE	MCX_IOCTL(0x901)
#define IOCTL_SERIAL_SET_SYNC_STATE	MCX_IOCTL(0x902)
#define IOCTL_SERIAL_CMD		MCX_IOCTL(0x903)
#define IOCTL_SERIAL_CMD_AUTO		MCX_IOCTL(0x904)
#define IOCTL_SERIAL_RUN01		MCX_IOCTL(0x905)
#define IOCTL_SERIAL_RUN02		MCX_IOCTL(0x906)

#endif  /* Windows NT & 95 */

typedef struct _MCX_SYNCHRONIZATION_PARAMETERS {
    unchar SynchronousMode;
#define MCX_SYNC_CHAR		0	/* also means FALSE (NOT synchronous) */
#define MCX_SYNC_MONOSYNC	1	/* not implemented */
#define MCX_SYNC_BISYNC		2	/* HDX, trames delimitees par CD/RTS */
#define MCX_SYNC_EXTERNAL	3	/* not implemented */
#define MCX_SYNC_HDLC		4
#define MCX_SYNC_LAPB		5	/* LAPB/HDLC FDX */
#define MCX_SYNC_X25		6	/* X25/LAPB/HDLC FDX */
    unchar Duplex;
#define MCX_FULL_DUPLEX		0
#define MCX_HALF_DUPLEX		1	/* RTS descend apres chaque trame
#define MCX_SIMPLEX		2	/* not implemented */
					/* --------- horloges --------- */
					/*    ETTD      ETCD NULL-MODEM */
					/* ---------------------------- */
    unchar TransmitClockSource;		/*    TXCI	BRG	BRG	*/
    unchar ReceiveClockSource;		/*    RXC	BRG	RXC	*/
    unchar TxClockPinSource;		/* TRXC_HIGH	BRG	BRG	*/
					/* ---------------------------- */
#define MCX_CLOCK_TRXC_HIGH	0	/* alias pour le define suivant */
#define MCX_CLOCK_RXC		0	/* toutes les combinaisons */
#define MCX_CLOCK_TXCI		1	/* ne sont pas supportees. */
#define MCX_CLOCK_BRG		2
#define MCX_CLOCK_DPLL		3
    unchar MonosyncChar;
    unchar BisyncChar;
} MCX_SYNCHRONIZATION_PARAMETERS, *PMCX_SYNCHRONIZATION_PARAMETERS;

#define MCX_SYNC_MAX_PACKET	1022	/* taille max d'une trame synchrone */

#endif /* MCC_MCX_H */
