/*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  MCXCTL.H    DEFINITIONS POUR FONCTIONS IOCTL MCX SPECIFIQUES   %%
%%                                                                 %%
%%  Rev 1.00    Microsoft C 4.0               ACKSYS 1998 - ERL   %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/

#define IOCTL_SERIAL_INFOBOARD  MCX_IOCTL(0x920)
#define IOCTL_SERIAL_INFOCHAN   MCX_IOCTL(0x921)

//MCX_DESCRIPTOR card_stat bit definition
#define INITDONE        0x01    // Carte initialise si 1
#define MULTIPRO        0x02    // Carte multipro
#define LITE570         0x04    // Carte Lite/570
#define MCCBOARD        0x80    // Carte MCC

// VALEURS POUR CANALINFO.Mcr
#define RTSMASK       0x0001    // Image RTS
#define DTRMASK       0x0002    // Image DTR

// VALEURS POUR PORTINFO.OpMode
#define RS232            0x0    // Mode RS 232
#define RS422            0x1    // Mode RS 422
#define RS485            0x2    // Mode RS 485
#define RS449            0x3    // Mode RS 449
#define V35              0x4    // Mode V35
#define V36              0x5    // Mode RS 485
#define EIA530           0x6    // Mode RS 485
#define EIA530A          0x7    // Mode RS 485
#define HIZ              0x8    // Mode RS 485
#define MS422           0x82    // Mode RS 422 M/S  (485 4 fils)

// VALEURS POUR CANALINFO.MintrCond
#define IT_RxAllChars   0x0100
#define IT_RxModulo     0x0200
#define IT_FirstChar    0x0200
#define IT_RxFull       0x0400
#define IT_RxNotEmpty   0x0480
#define IT_RxString     0x0800
#define IT_RxTimeOut    0x1000
#define IT_RxError      0x2000
#define IT_DeltaSig     0x4000
#define IT_TxEmpty      0x8000


// VALEURS POUR CANALINFO.BpClk
#define OSC16    16000000         // Frequence Oscillateur = 16MHz
#define OSC14    14745600         // Frequence Oscillateur = 14.7456 MHz
#define OSC2      2457600         // Frequence Oscillateur Mcc = 2.4576 MHz


/************************************************************
* STRUCTURE DES INFOS PROPRES A CHAQUE CARTE MCX            *
************************************************************/
typedef struct BoardInfo {
    WORD            MaxChan;            // Channel number
    WORD            mb_addr;            // Mcx mailbox address
    WORD            mcx_irq;            // IRQ level pour cette carte
    DWORD           reserved_01[9];     // Rserv
    PMCC_MAILBOX    mb_ptr;             // Adresse 32b (flat) MCX Mailbox
    PWORD           tfree;              // Pointeur sur compteurs TX
    PWORD           rxcnt;              // Pointeur sur compteurs RX
    DWORD           reserved_02;        // Rserv
    WORD            mcx_port;           // Adresse port I/O MCX
    WORD            card_stat;          // Status
    BYTE        	firmware;           // Rvision Firmware de la carte
    BYTE        	codeconf[4];        // Code confidentiel 8 car.
    BYTE        	mcxid[3];           // ID = Mcx ou Mcc
    BYTE        	chanb;              // Nombre de canaux d'aprs la carte
    BYTE        	config;             // Voir dtail dans la doc
    BYTE        	frequency;          // Frquence CPU MCX
    BYTE        	mcxdosrev;          // Rvision bios mcxdos
    BYTE        	mcxdbgrev;          // Rvision mcxdebug
    BYTE        	biosrev;            // rvision BIOS
}BOARDINFO, *PBOARDINFO;



/************************************************************
* STRUCTURE COMMANDE IOControl DES INFOS PORT               *
************************************************************/
typedef struct CANALINFO {
    union {
            WORD    PortId;
        	struct {
               BYTE Canal;          	// No de canal pour la carte (1  64)
               BYTE Carte;          	// No de carte (0 -> 3)
            };
    };
    CHAR            PortName[14];       // Nom du port
    DWORD           BpClk;              // Frquence Oscillateur du BP
    WORD            MintrCond;          // MINTR Conditions
    WORD            RxTrigger;          // Seuil pour Int modulo
    WORD            RxSize;             // Taille du tampon RX on board
    WORD            TxSize;             // Taille du tampon TX on Board
    WORD            BaudRate;           // Vitesse Courante
    BYTE            ByteSize;           // Nombre de bits/caractre, 4-8
    BYTE            Parity;            	// 0-4=None,Odd,Even,Mark,Space
    BYTE            StopBits;           // 0,1,2 = 1, 1.5, 2
    BYTE            OpMode;             // Operating Mode
    BYTE            Mcr;                // Modem control image
    BYTE            Msr;                // Modem status image
    BYTE            RxEnb;              // RxEnable state
    BYTE            reserved_01;
    DWORD           reserved_02;
    BYTE            reserved_03;
    BYTE            HndShkMode;         // Mode de handshake
    WORD            reserved_04;
    DWORD           RxQueueCnt;         // Nombre de car. tampon Rx pc
    DWORD           TxQueueCnt;         // Nombre de car. tampon Tx pc
    WORD            RxBoardCnt;         // Nombre de car. tampon Rx carte
    WORD            TxBoardCnt;         // Nombre de car. tampon Tx carte
    DWORD           RecvTrigger;
    DWORD           SendTrigger;
    DWORD           EvtMask;
    DWORD           reserved[14];
} CANALINFO, *PCANALINFO;
